@@ -1,5 +1,5 @@
 stdThreadMax <- function() {
-    nThreads <- .Call(Algos_cpp11GetNumThreads)
+    nThreads <- .Call(`_RcppAlgos_cpp11GetNumThreads`)
     if (nThreads < 1L || is.na(nThreads) || is.null(nThreads)) nThreads = 1L
     return(nThreads)
 }
