@@ -16,7 +16,7 @@ test_that("permuteGeneral produces correct results with no constraints and no re
     ## Constraint should not be carried out if no comparisonFun is given
     expect_equal(permuteGeneral(3, 3, constraintFun = "sum",
                                 limitConstraints = 100), permuteGeneral(1:3, 3))
-    
+
     expect_equal(nrow(permuteGeneral(8, 8)), factorial(8))
 
     set.seed(11)
@@ -25,7 +25,8 @@ test_that("permuteGeneral produces correct results with no constraints and no re
                  permuteGeneral(myNums, 3, freqs = rep(1, 5)))
 
     expect_equal(ncol(permuteGeneral(5, 3)), 3)
-    expect_equal(ncol(permuteGeneral(5, 3, FALSE, constraintFun = "prod", keepResults = TRUE)), 4)
+    expect_equal(ncol(permuteGeneral(5, 3, FALSE, constraintFun = "prod",
+                                     keepResults = TRUE)), 4)
     expect_equal(nrow(permuteGeneral(5, 3, upper = 20)), 20)
     expect_equal(nrow(permuteGeneral(5, 3, FALSE, constraintFun = "prod",
                                      keepResults = TRUE, upper = 10L)), 10)
@@ -50,9 +51,9 @@ test_that("permuteGeneral produces correct results with no constraints and has r
 
     expect_equal(nrow(permuteGeneral(5, 3, TRUE, upper = 10)), 10)
     expect_equal(ncol(permuteGeneral(5, 3, TRUE, constraintFun = "prod", keepResults = TRUE)), 4)
-    
+
     ## In older versions the test below would fail b/c it would produce NaNs during prep
-    expect_equal(nrow(permuteGeneral(2, 180, freqs = c(180, 2))), 
+    expect_equal(nrow(permuteGeneral(2, 180, freqs = c(180, 2))),
                  permuteCount(2, 180, freqs = c(180, 2)))
 })
 
@@ -69,6 +70,14 @@ test_that("permuteGeneral produces correct results with no constraints for multi
     expect_equal(permuteGeneral(month.name[1:5], 3, TRUE),
                  permuteGeneral(month.name[1:5], 3, freqs = rep(3, 5)))
 
+    all.equal(t(as.matrix(partitions::multiset(rep(1:4, times = c(1:3, 6))))),
+              permuteGeneral(4, freqs = c(1:3, 6), nThreads = 2))
+
+    expect_equal(permuteGeneral(letters[1:3], freqs = 1:3),
+                 matrix(letters[1:3][t(partitions::multiset(rep(1:3, times = 1:3)))], ncol = 6))
+
+    expect_equal(permuteGeneral(3, lower = 3), permuteGeneral(3)[3:6, ])
+
     myNums2 <- 1:10 / 3
     expect_equal(permuteGeneral(myNums2, 5, freqs = rep(2, 10))[80000:90000, ],
                  permuteGeneral(myNums2, 5, freqs = rep(2, 10),
@@ -83,7 +92,7 @@ test_that("permuteGeneral produces correct results with no constraints for multi
 
     expect_equal(permuteGeneral(5, 5),
                  permuteGeneral(5, 5, freqs = rep(1, 5)))
-    
+
     expect_equal(permuteCount(30, freqs = rep(1:2, 15)),
                  permuteCount(30, 45, freqs = rep(1:2, 15)))
 
@@ -96,12 +105,12 @@ test_that("permuteGeneral produces correct results with constraints", {
     expect_equal(nrow(permuteGeneral(15, 7,
                                      comparisonFun = "==", constraintFun = "sum",
                                      limitConstraints = 80, upper = 100)), 100)
-    
-    expect_equal(nrow(permuteGeneral(15, 7, TRUE, 
+
+    expect_equal(nrow(permuteGeneral(15, 7, TRUE,
                                      comparisonFun = "==", constraintFun = "sum",
                                      limitConstraints = 80, upper = 200)), 200)
-    
-    expect_equal(nrow(permuteGeneral(15, 7, freqs = rep(1:5, 3), 
+
+    expect_equal(nrow(permuteGeneral(15, 7, freqs = rep(1:5, 3),
                                      comparisonFun = "==", constraintFun = "sum",
                                      limitConstraints = 80, upper = 220)), 220)
 
@@ -117,7 +126,7 @@ test_that("permuteGeneral produces correct results with constraints", {
     expect_true(all(permuteGeneral(5, 5L, TRUE,
                                    constraintFun = "min",
                                    comparisonFun = "<", limitConstraints = 3,
-                                       keepResults = TRUE)[,6] < 3))
+                                   keepResults = TRUE)[,6] < 3))
 
     expect_true(all(permuteGeneral(5, 5, TRUE,
                                    constraintFun = "prod",
@@ -127,7 +136,7 @@ test_that("permuteGeneral produces correct results with constraints", {
     expect_true(all(permuteGeneral(5, 3, FALSE,
                                    constraintFun = "max",
                                    comparisonFun = "=<", limitConstraints = 4,
-                                keepResults = TRUE)[,4] <= 4))
+                                   keepResults = TRUE)[,4] <= 4))
 
     expect_true(all(permuteGeneral(3, 5, TRUE,
                                    constraintFun = "mean",
@@ -136,8 +145,8 @@ test_that("permuteGeneral produces correct results with constraints", {
 
     expect_true(all(permuteGeneral(5, 5, FALSE, constraintFun = "sum",
                                    comparisonFun = ">", limitConstraints = 18,
-                                     freqs = c(1,2,1,2,4),
-                                     keepResults = TRUE)[,6] > 18))
+                                   freqs = c(1,2,1,2,4),
+                                   keepResults = TRUE)[,6] > 18))
 
     expect_equal(sum(permuteGeneral(4, 6, freqs = c(1,3,2,2),
                                    constraintFun = "sum",
@@ -192,9 +201,11 @@ test_that("permuteGeneral produces correct results with exotic constraints", {
         for (j in a) {
             for (k in b) {
                 myComp <- c(j, k)
-                myTest <- permuteGeneral(c(-6:(-1),1:2), 5, freqs = c(rep(1:3, 2), 2:3),
-                                       constraintFun = "prod", comparisonFun = myComp,
-                                       limitConstraints = c(q[2], q[4]))
+                myTest <- permuteGeneral(c(-6:(-1),1:2), 5,
+                                         freqs = c(rep(1:3, 2), 2:3),
+                                         constraintFun = "prod",
+                                         comparisonFun = myComp,
+                                         limitConstraints = c(q[2], q[4]))
                 fun1 <- match.fun(j)
                 fun2 <- match.fun(k)
 
@@ -204,7 +215,7 @@ test_that("permuteGeneral produces correct results with exotic constraints", {
                     temp <- allPerms[fun1(theSum, q[2]) & fun2(theSum, q[4]),]
                 }
 
-                expect_equal(temp, myTest)
+                expect_equal(temp, myTest, info = c(myComp, q[2], q[4]))
             }
         }
     }
@@ -286,36 +297,54 @@ test_that("permuteGeneral produces correct results with exotic constraints", {
 test_that("permuteGeneral produces correct results with use of FUN", {
     test <- permuteGeneral(6, 6, constraintFun = "mean")[, 7]
     expect_equal(as.vector(test), unlist(permuteGeneral(6, 6, FUN = mean)))
-    
+
     expect_equal(sum(unlist(permuteGeneral(as.complex(c(1, -1, -1i, 1i)), 3,
                                            FUN = function(x) sum(Re(x))))), 0)
-    
+
+    expect_equal(class(permuteGeneral(as.complex(1:5 + 1i),
+                                      3, TRUE, FUN = prod, FUN.VALUE = 1i)),
+                 "complex")
+    expect_equal(permuteGeneral(c("A", "B", "C"), 2,
+                                FUN = function(x) paste(x, collapse = ""),
+                                FUN.VALUE = "A"),
+                 c("AB", "AC", "BA", "BC", "CA", "CB"))
+    expect_equal(apply(expand.grid(rep(list(as.complex(1:3 + 1i)), 5)), 1,
+                         function(x) sum(rev(x) / (as.complex(1:5 + 1i)))),
+                 permuteGeneral(as.complex(1:3 + 1i), 5, TRUE,
+                                FUN = function(x) sum(x / (as.complex(1:5 + 1i))),
+                                FUN.VALUE = as.complex(1)))
+    expect_equal(permuteGeneral(as.complex(1:3), FUN = function(x) as.numeric(mean(x)),
+                                FUN.VALUE = 2), rep(2, permuteCount(3)))
+    expect_equal(class(permuteGeneral(c(TRUE, FALSE), 5, TRUE,
+                                      FUN = any, FUN.VALUE = 1L)), "integer")
+
     test <- permuteGeneral(6, 6, lower = 100, constraintFun = "prod")[, 7]
     expect_equal(as.vector(test), unlist(permuteGeneral(6, 6, lower = 100, FUN = prod)))
-    
+
     test <- permuteGeneral(10, 5, constraintFun = "sum", keepResults = TRUE)
     expect_equal(as.vector(test[,6]), unlist(permuteGeneral(10, 5, FUN = sum)))
 
     test <- permuteGeneral(10, 4, TRUE)
     testFun <- apply(test, 1, function(x) mean(x) * 2)
-    expect_equal(testFun, unlist(permuteGeneral(10, 4, T, FUN = function(x) {mean(x) * 2})))
+    expect_equal(testFun, unlist(permuteGeneral(10, 4, T,
+                                                FUN = function(x) {mean(x) * 2})))
 
     test <- permuteGeneral(8, 4, freqs = rep(1:4, 2))
     testFun <- lapply(1:nrow(test), function(x) cumsum(test[x, ]))
     expect_equal(testFun, permuteGeneral(8, 4, freqs = rep(1:4, 2), FUN = cumsum))
-    
+
     test <- apply(permuteGeneral(4, 8, freqs = c(1,3,1,3)), 1, {
         function(x) paste0(cumprod(x), collapse = "")
     })
-    
+
     testFun <- unlist(permuteGeneral(4, 8, freqs = c(1,3,1,3), FUN = function(x) {
         paste0(cumprod(x), collapse = "")
     }))
-    
+
     expect_equal(test, testFun)
-    
-    expect_equal(permuteGeneral(4, 8, freqs = c(1,3,1,3), 
-                                constraintFun = "sum", nThreads = 2)[, 9], 
+
+    expect_equal(permuteGeneral(4, 8, freqs = c(1,3,1,3),
+                                constraintFun = "sum", nThreads = 2)[, 9],
                  rowSums(permuteGeneral(4, 8, freqs = c(1,3,1,3), nThreads = 2)))
 })
 
